@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 #
-# Copyright Red Hat, Inc.
+# Copyright 2020-2023 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,11 +14,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import argparse
+import sys
 from argparse import ArgumentParser
+from datetime import datetime
 from dciclient.version import __version__
-
-_default_dci_cs_url = "http://127.0.0.1:5000"
-_default_sso_url = "http://127.0.0.1:8180"
+from dciclient.v1.shell_commands import context as dci_context
 
 
 def _create_boolean_flags(parser, flags, default, dest=None):
@@ -38,71 +39,28 @@ def _create_array_argument(parser, argument_name, help):
     )
 
 
+def _date_isoformat(v):
+    try:
+        datetime.strptime(v, "%Y-%m-%dT%H:%M:%S.%f")
+    except ValueError:
+        raise argparse.ArgumentTypeError("'%s' is not an iso format date" % v)
+    return v
+
+
+def print_version_compatible_py27(args):
+    if args == ["--version"]:
+        print("dcictl %s" % __version__)
+        sys.exit()
+
+
 def parse_arguments(args, environment={}):
     base_parser = ArgumentParser(add_help=False)
-    base_parser.add_argument("--verbose", "--long", default=False, action="store_true")
 
     parser = ArgumentParser(prog="dcictl")
-    parser.add_argument(
-        "--version", action="version", version="%(prog)s " + __version__
-    )
-    parser.add_argument(
-        "--dci-login",
-        default=environment.get("DCI_LOGIN", None),
-        help="DCI login or 'DCI_LOGIN' environment variable.",
-    )
-    parser.add_argument(
-        "--dci-password",
-        default=environment.get("DCI_PASSWORD", None),
-        help="DCI password or 'DCI_PASSWORD' environment variable.",
-    )
-    parser.add_argument(
-        "--dci-client-id",
-        default=environment.get("DCI_CLIENT_ID", None),
-        help="DCI CLIENt ID or 'DCI_CLIENT_ID' environment variable.",
-    )
-    parser.add_argument(
-        "--dci-api-secret",
-        default=environment.get("DCI_API_SECRET", None),
-        help="DCI API secret or 'DCI_API_SECRET' environment variable.",
-    )
-    parser.add_argument(
-        "--dci-cs-url",
-        default=environment.get("DCI_CS_URL", _default_dci_cs_url),
-        help="DCI control server url, default to '%s'." % _default_dci_cs_url,
-    )
-    parser.add_argument(
-        "--sso-url",
-        default=environment.get("SSO_URL", _default_sso_url),
-        help="SSO url, default to '%s'." % _default_sso_url,
-    )
-    parser.add_argument(
-        "--sso-username",
-        default=environment.get("SSO_USERNAME"),
-        help="SSO username or 'SSO_USERNAME' environment variable.",
-    )
-    parser.add_argument(
-        "--sso-password",
-        default=environment.get("SSO_PASSWORD"),
-        help="SSO password or 'SSO_PASSWORD' environment variable.",
-    )
-    parser.add_argument(
-        "--sso-token",
-        default=environment.get("SSO_TOKEN"),
-        help="SSO token or 'SSO_TOKEN' environment variable.",
-    )
-    parser.add_argument(
-        "--refresh-sso-token",
-        default=False,
-        action="store_true",
-        help="Refresh the token",
-    )
-    parser.add_argument(
-        "--format",
-        default="table",
-        choices=["table", "json", "csv", "tsv"],
-        help="Output format",
-    )
+
+    print_version_compatible_py27(args)
+
+    dci_context.parse_auth_arguments(parser, environment)
 
     subparsers = parser.add_subparsers()
     # user commands
@@ -113,6 +71,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="user-list")
 
     p = subparsers.add_parser(
@@ -158,6 +117,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="team-list")
 
     p = subparsers.add_parser(
@@ -165,6 +125,12 @@ def parse_arguments(args, environment={}):
     )
     p.add_argument("--name", required=True)
     p.add_argument("--country")
+    _create_boolean_flags(
+        p,
+        "--pre-release-access/--no-pre-release-access",
+        default=False,
+        dest="has_pre_release_access",
+    )
     _create_boolean_flags(p, "--active/--no-active", default=True, dest="state")
     p.set_defaults(command="team-create")
 
@@ -177,6 +143,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--country")
     _create_boolean_flags(p, "--active/--no-active", default=None, dest="state")
     _create_boolean_flags(p, "--external/--no-external", default=None, dest="external")
+    _create_boolean_flags(
+        p,
+        "--pre-release-access/--no-pre-release-access",
+        default=None,
+        dest="has_pre_release_access",
+    )
     p.set_defaults(command="team-update")
 
     p = subparsers.add_parser(
@@ -190,42 +162,6 @@ def parse_arguments(args, environment={}):
     p.add_argument("id")
     p.set_defaults(command="team-show")
 
-    # analytic commands
-    p = subparsers.add_parser(
-        "analytic-list", help="List all analytics.", parents=[base_parser]
-    )
-    p.add_argument("--job-id")
-    p.set_defaults(command="analytic-list")
-
-    p = subparsers.add_parser(
-        "analytic-create", help="Create a analytic.", parents=[base_parser]
-    )
-    p.add_argument("--job-id", required=True)
-    p.add_argument("--name", required=True)
-    p.add_argument("--type", required=True)
-    p.add_argument("--url")
-    p.add_argument("--data", default="{}")
-    p.set_defaults(command="analytic-create")
-
-    p = subparsers.add_parser(
-        "analytic-update", help="Update a analytic.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--etag", required=True)
-    p.add_argument("--job-id", required=True)
-    p.add_argument("--name", required=True)
-    p.add_argument("--type", required=True)
-    p.add_argument("--url")
-    p.add_argument("--data", default="{}")
-    p.set_defaults(command="analytic-update")
-
-    p = subparsers.add_parser(
-        "analytic-show", help="Show a analytic.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--job-id", required=True)
-    p.set_defaults(command="analytic-show")
-
     # product commands
     p = subparsers.add_parser(
         "product-list", help="List all products.", parents=[base_parser]
@@ -234,6 +170,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="product-list")
 
     p = subparsers.add_parser(
@@ -294,6 +231,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="product-list-teams")
 
     # feeder commands
@@ -304,6 +242,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="feeder-list")
 
     p = subparsers.add_parser(
@@ -356,6 +295,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="topic-list")
 
     p = subparsers.add_parser(
@@ -382,7 +322,6 @@ def parse_arguments(args, environment={}):
     p.add_argument(
         "--component_types", default=None, help="Component types separated by commas."
     )
-    p.add_argument("--label")
     p.add_argument("--next-topic-id")
     _create_boolean_flags(p, "--active/--no-active", default=False, dest="state")
     _create_boolean_flags(
@@ -396,36 +335,13 @@ def parse_arguments(args, environment={}):
         "topic-delete", help="Delete a topic.", parents=[base_parser]
     )
     p.add_argument("id")
+    p.add_argument("--etag", required=True)
     p.set_defaults(command="topic-delete")
 
     p = subparsers.add_parser("topic-show", help="Show a topic.", parents=[base_parser])
     p.add_argument("id")
     p.set_defaults(command="topic-show")
 
-    p = subparsers.add_parser(
-        "topic-attach-team", help="Attach a team to a topic.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--team-id")
-    p.set_defaults(command="topic-attach-team")
-
-    p = subparsers.add_parser(
-        "topic-unattach-team", help="Unattach a team to a topic.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--team-id")
-    p.set_defaults(command="topic-unattach-team")
-
-    p = subparsers.add_parser(
-        "topic-list-team", help="List teams attached to a topic.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--sort", default="-created_at")
-    p.add_argument("--limit", default=50)
-    p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
-    p.set_defaults(command="topic-list-team")
-
     # jobstate commands
     p = subparsers.add_parser(
         "jobstate-show", help="Show a jobstate.", parents=[base_parser]
@@ -433,6 +349,14 @@ def parse_arguments(args, environment={}):
     p.add_argument("id")
     p.set_defaults(command="jobstate-show")
 
+    p = subparsers.add_parser(
+        "jobstate-create", help="Create a jobstate.", parents=[base_parser]
+    )
+    p.add_argument("--job-id", required=True)
+    p.add_argument("--status", required=True)
+    p.add_argument("--comment", default="")
+    p.set_defaults(command="jobstate-create")
+
     # component commands
     p = subparsers.add_parser(
         "component-list", help="List all components.", parents=[base_parser]
@@ -442,23 +366,24 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="component-list")
 
     p = subparsers.add_parser(
         "component-create", help="Create a component.", parents=[base_parser]
     )
-    p.add_argument("--name", required=True, help="Name of component")
+    p.add_argument("display_name", metavar="name")
     p.add_argument("--type", required=True, help="Type of component")
     p.add_argument("--topic-id", required=True, help="Topic ID")
+    p.add_argument("--team-id")
     _create_array_argument(p, "--tags", help="Comma separated list of tags")
-    p.add_argument(
-        "--canonical_project_name", default=None, help="Canoncial project name."
-    )
-    p.add_argument("--title", help="Title of component")
-    p.add_argument("--message", help="Component message")
     p.add_argument("--url", help="URL to look for the component")
     _create_boolean_flags(p, "--active/--no-active", default=True, dest="state")
     p.add_argument("--data", default="{}", help="Data to pass (JSON)")
+    p.add_argument(
+        "--released-at", default=None, type=_date_isoformat, help="The release date"
+    )
+    p.add_argument("--version", required=False, help="Version of the component")
     p.set_defaults(command="component-create")
 
     p = subparsers.add_parser(
@@ -466,12 +391,21 @@ def parse_arguments(args, environment={}):
     )
     p.add_argument("id")
     _create_boolean_flags(p, "--active/--no-active", default=None, dest="state")
+    p.add_argument(
+        "--display-name", required=False, help="Display name of the component"
+    )
+    p.add_argument("--type", required=False, help="Type of component")
+    _create_array_argument(p, "--tags", help="Comma separated list of tags")
+    p.add_argument("--url", help="URL to look for the component")
+    p.add_argument("--data", default="{}", help="Data to pass (JSON)")
+    p.add_argument("--version", required=False, help="Version of the component")
     p.set_defaults(command="component-update")
 
     p = subparsers.add_parser(
         "component-delete", help="Delete a component.", parents=[base_parser]
     )
     p.add_argument("id")
+    p.add_argument("--etag", required=True)
     p.set_defaults(command="component-delete")
 
     p = subparsers.add_parser(
@@ -480,35 +414,6 @@ def parse_arguments(args, environment={}):
     p.add_argument("id")
     p.set_defaults(command="component-show")
 
-    p = subparsers.add_parser(
-        "component-attach-issue",
-        help="Attach an issue to a component.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--url", required=True)
-    p.set_defaults(command="component-attach-issue")
-
-    p = subparsers.add_parser(
-        "component-unattach-issue",
-        help="Unattach an issue to a component.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--issue-id", required=True)
-    p.set_defaults(command="component-unattach-issue")
-
-    p = subparsers.add_parser(
-        "component-list-issue",
-        help="List all component attached issues.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--sort", default="-created_at")
-    p.add_argument("--limit", default=50)
-    p.add_argument("--offset", default=0)
-    p.set_defaults(command="component-list-issue")
-
     p = subparsers.add_parser(
         "component-file-upload",
         help="Attach a file to a component.",
@@ -545,6 +450,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="component-file-list")
 
     p = subparsers.add_parser(
@@ -552,6 +458,7 @@ def parse_arguments(args, environment={}):
     )
     p.add_argument("id")
     p.add_argument("--file-id", required=True)
+    p.add_argument("--etag", required=True)
     p.set_defaults(command="component-file-delete")
 
     # file commands
@@ -563,6 +470,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="file-list")
 
     p = subparsers.add_parser("file-show", help="Show a file.", parents=[base_parser])
@@ -581,6 +489,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=10)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="job-list")
 
     p = subparsers.add_parser("job-show", help="Show a job.", parents=[base_parser])
@@ -592,6 +501,18 @@ def parse_arguments(args, environment={}):
     p.add_argument("--etag", required=True)
     p.set_defaults(command="job-delete")
 
+    p = subparsers.add_parser("job-update", help="Update a job.", parents=[base_parser])
+    p.add_argument("id")
+    _create_boolean_flags(p, "--active/--no-active", default=None, dest="state")
+    p.add_argument("--name", required=False, help="Name of the job")
+    p.add_argument("--comment", required=False, help="Comment of the job")
+    _create_array_argument(p, "--tags", help="Comma separated list of tags")
+    p.add_argument("--status", default=None, help="Status of the job.")
+    p.add_argument("--status_reason", default=None, help="Status reason of the job.")
+    p.add_argument("--configuration", help="Configuration of the job.")
+    p.add_argument("--url", help="URL to look for the component")
+    p.set_defaults(command="job-update")
+
     p = subparsers.add_parser(
         "job-results", help="List all job results.", parents=[base_parser]
     )
@@ -601,67 +522,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--offset", default=0)
     p.set_defaults(command="job-results")
 
-    p = subparsers.add_parser(
-        "job-attach-issue", help="Attach an issue to a job.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--url", required=True)
-    p.set_defaults(command="job-attach-issue")
-
-    p = subparsers.add_parser(
-        "job-unattach-issue", help="Unattach an issue to a job.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--issue-id", required=True)
-    p.set_defaults(command="job-unattach-issue")
-
-    p = subparsers.add_parser(
-        "job-list-issue", help="List all job attached issues.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--sort", default="-created_at")
-    p.add_argument("--limit", default=50)
-    p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
-    p.set_defaults(command="job-list-issue")
-
     p = subparsers.add_parser(
         "job-output", help="Show the job output.", parents=[base_parser]
     )
     p.add_argument("id")
     p.set_defaults(command="job-output")
 
-    p = subparsers.add_parser(
-        "job-list-test", help="List all tests attached issues.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--sort", default="-created_at")
-    p.add_argument("--limit", default=50)
-    p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
-    p.set_defaults(command="job-list-issue")
-
-    p = subparsers.add_parser(
-        "job-add-tag", help="Add a tag to a job.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("name")
-    p.set_defaults(command="job-add-tag")
-
-    p = subparsers.add_parser(
-        "job-delete-tag", help="Drop a tag to a job.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("tag_id")
-    p.add_argument("tag_name")
-    p.set_defaults(command="job-delete-tag")
-
-    p = subparsers.add_parser(
-        "job-list-tags", help="List all the tags of a job.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.set_defaults(command="job-list-tags")
-
     p = subparsers.add_parser(
         "job-upload-file", help="Attach a file to a job.", parents=[base_parser]
     )
@@ -669,16 +535,15 @@ def parse_arguments(args, environment={}):
     p.add_argument("--name", required=True)
     p.add_argument("--path", required=True, dest="file_path")
     p.add_argument("--jobstate-id")
-    p.add_argument("--test-id")
     p.add_argument("--mime")
     p.set_defaults(command="job-upload-file")
 
     p = subparsers.add_parser(
         "job-download-file", help="Retrieve a job file.", parents=[base_parser]
     )
-    p.add_argument("id")
+    p.add_argument("id", help="The job id.")
     p.add_argument("--file-id", required=True)
-    p.add_argument("--target", required=True)
+    p.add_argument("--target", required=True, help="Destination file path.")
     p.set_defaults(command="job-download-file")
 
     p = subparsers.add_parser(
@@ -696,6 +561,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="job-list-file")
 
     p = subparsers.add_parser(
@@ -705,43 +571,20 @@ def parse_arguments(args, environment={}):
     p.add_argument("--file-id", required=True)
     p.set_defaults(command="job-delete-file")
 
-    # test commands
     p = subparsers.add_parser(
-        "test-list", help="List all tests.", parents=[base_parser]
-    )
-    p.add_argument("--sort", default="-created_at")
-    p.add_argument("--limit", default=50)
-    p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
-    p.set_defaults(command="test-list")
-
-    p = subparsers.add_parser(
-        "test-create", help="Create a test.", parents=[base_parser]
-    )
-    p.add_argument("--name")
-    p.add_argument("--data", default="{}")
-    _create_boolean_flags(p, "--active/--no-active", default=True, dest="state")
-    p.set_defaults(command="test-create")
-
-    p = subparsers.add_parser(
-        "test-update", help="Update a test.", parents=[base_parser]
+        "job-add-key-value", help="Job add key/value.", parents=[base_parser]
     )
     p.add_argument("id")
-    p.add_argument("--etag", required=True)
-    p.add_argument("--name")
-    p.add_argument("--data", default="{}")
-    _create_boolean_flags(p, "--active/--no-active", default=None, dest="state")
-    p.set_defaults(command="test-update")
+    p.add_argument("key", type=str)
+    p.add_argument("value", type=float)
+    p.set_defaults(command="job-add-key-value")
 
     p = subparsers.add_parser(
-        "test-delete", help="Delete a test.", parents=[base_parser]
+        "job-delete-key-value", help="Job add key/value.", parents=[base_parser]
     )
     p.add_argument("id")
-    p.set_defaults(command="test-delete")
-
-    p = subparsers.add_parser("test-show", help="Show a test.", parents=[base_parser])
-    p.add_argument("id")
-    p.set_defaults(command="test-show")
+    p.add_argument("key")
+    p.set_defaults(command="job-delete-key-value")
 
     # remoteci commands
     p = subparsers.add_parser(
@@ -751,6 +594,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="remoteci-list")
 
     p = subparsers.add_parser(
@@ -795,36 +639,6 @@ def parse_arguments(args, environment={}):
     p.add_argument("--keys", default=None)
     p.set_defaults(command="remoteci-get-data")
 
-    p = subparsers.add_parser(
-        "remoteci-attach-test",
-        help="Attach a test to a remoteci.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--test-id", required=True)
-    p.set_defaults(command="remoteci-attach-test")
-
-    p = subparsers.add_parser(
-        "remoteci-unattach-test",
-        help="Unattach a test to a remoteci.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--test-id", required=True)
-    p.set_defaults(command="remoteci-unattach-test")
-
-    p = subparsers.add_parser(
-        "remoteci-list-test",
-        help="List tests attached to a remoteci.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--sort", default="-created_at")
-    p.add_argument("--limit", default=50)
-    p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
-    p.set_defaults(command="remoteci-list-test")
-
     p = subparsers.add_parser(
         "remoteci-reset-api-secret",
         help="Reset a remoteci api secret.",
@@ -834,15 +648,6 @@ def parse_arguments(args, environment={}):
     p.add_argument("--etag", required=True)
     p.set_defaults(command="remoteci-reset-api-secret")
 
-    p = subparsers.add_parser(
-        "remoteci-refresh-keys",
-        help="Refresh a remoteci key pair.",
-        parents=[base_parser],
-    )
-    p.add_argument("id")
-    p.add_argument("--etag", required=True)
-    p.set_defaults(command="remoteci-refresh-keys")
-
     p = subparsers.add_parser(
         "remoteci-attach-user",
         help="Attach a user to a remoteci.",
@@ -871,6 +676,7 @@ def parse_arguments(args, environment={}):
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
     p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="remoteci-list-user")
 
     # purge commands
@@ -885,5 +691,65 @@ def parse_arguments(args, environment={}):
     )
     p.set_defaults(command="purge")
 
+    # pipeline commands
+    p = subparsers.add_parser(
+        "pipeline-create",
+        help="Create a new pipeline.",
+        parents=[base_parser],
+    )
+    p.add_argument("--name", required=True)
+    p.add_argument("--team-id", required=True)
+    p.set_defaults(command="pipeline-create")
+
+    p = subparsers.add_parser(
+        "pipeline-show",
+        help="Show a pipeline.",
+        parents=[base_parser],
+    )
+    p.add_argument("id")
+    p.set_defaults(command="pipeline-show")
+
+    p = subparsers.add_parser(
+        "pipeline-list", help="List all pipelines.", parents=[base_parser]
+    )
+    p.add_argument("--sort", default="-created_at")
+    p.add_argument("--limit", default=50)
+    p.add_argument("--offset", default=0)
+    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument("--query", help="Query language dsl", required=False)
+    p.set_defaults(command="pipeline-list")
+
+    p = subparsers.add_parser(
+        "pipeline-update", help="Update a pipeline.", parents=[base_parser]
+    )
+    p.add_argument("id")
+    p.add_argument("--etag", required=True)
+    _create_boolean_flags(p, "--active/--no-active", default=None, dest="state")
+    p.add_argument("--name", required=False, help="Name of the pipeline.")
+    p.set_defaults(command="pipeline-update")
+
+    p = subparsers.add_parser(
+        "pipeline-delete", help="Delete a pipeline.", parents=[base_parser]
+    )
+    p.add_argument("id")
+    p.add_argument("--etag", required=True)
+    p.set_defaults(command="pipeline-delete")
+
+    p = subparsers.add_parser(
+        "pipeline-show-jobs",
+        help="Show jobs of a pipeline.",
+        parents=[base_parser],
+    )
+    p.add_argument("id")
+    p.add_argument("--sort", default="-created_at")
+    p.add_argument("--limit", default=50)
+    p.add_argument("--offset", default=0)
+    p.set_defaults(command="pipeline-show-jobs")
+
     args = parser.parse_args(args)
+
+    if "command" not in args:
+        parser.print_help()
+        sys.exit()
+
     return args
